@@ -2,22 +2,25 @@ import re
 from dataclasses import dataclass, field
 from enum import Enum
 from os import PathLike
-from typing import Any, Literal, Optional
+from typing import Any, Literal
 
 from ruamel.yaml import YAML
 from ruamel.yaml.comments import CommentedMap
-
-yaml = YAML()
-
+from ruamel.yaml.tokens import CommentToken
 
 GROUP_PATTERN = r"#\s*group:\s*(.+)$"
+yaml = YAML()
 
 
 def group_from_map(map: CommentedMap) -> str:
     """Extract group string from a comment line if it matches the group pattern."""
     if map.ca.comment:
-        for comment in map.ca.comment:
-            if comment is not None:
+        for comments in map.ca.comment:
+            if comments is None:
+                continue
+            elif isinstance(comments, CommentToken):
+                comments = [comments]
+            for comment in comments:
                 group_matches = re.finditer(GROUP_PATTERN, comment.value)
                 group_string = next((m.group(1).strip() for m in group_matches), "")
                 if group_string:
@@ -32,7 +35,7 @@ class Input:
     required: bool = False
     type: Literal["boolean", "number", "string"] = "string"
     default: bool | float | int | str | None = None
-    deprecationMessage: Optional[str] = None
+    deprecationMessage: str | None = None
     group: str = ""
 
 
@@ -52,6 +55,31 @@ class Secret:
     group: str = ""
 
 
+@dataclass
+class Step:
+    """Represents a step within a job."""
+
+    name: str
+    uses: str = ""  # For steps that use actions
+    run: str = ""  # For steps that run commands
+
+
+@dataclass
+class Job:
+    """Represents a job within a workflow."""
+
+    id: str
+    name: str
+    uses: str | None
+    steps: list[Step] = field(default_factory=list)
+    needs: list[str] = field(default_factory=list)  # Job dependencies
+
+    @property
+    def mermaid_id(self) -> str:
+        job_id_safe = self.id.replace("-", "_").replace(".", "_")
+        return f"job_{job_id_safe}"
+
+
 def _get_member(d: dict, key: str, error_message: str = "", default: Any = None) -> Any:
     if key not in d:
         if default is not None:
@@ -161,6 +189,7 @@ class Workflow:
     inputs: list[Input] = field(default_factory=list)
     secrets: list[Secret] = field(default_factory=list)
     outputs: list[Output] = field(default_factory=list)
+    jobs: dict[str, Job] = field(default_factory=dict)
     template: Literal["workflow.html.jinja"] = "workflow.html.jinja"
 
     @property
@@ -218,11 +247,11 @@ class Workflow:
                 workflow.permissions[key] = PermissionLevel.from_label(label)
         else:
             raise ValueError("permissions must be a string or a dictionary")
-        for job in data.get("jobs", {}).values():
-            if isinstance(permissions := job.get("permissions", {}), str):
+        for job_id, job_data in data.get("jobs", {}).items():
+            if isinstance(permissions := job_data.get("permissions", {}), str):
                 set_all_permissions(permissions)
             elif isinstance(permissions, dict):
-                for key, label in job.get("permissions", {}).items():
+                for key, label in job_data.get("permissions", {}).items():
                     if key in workflow.permissions:
                         permission = PermissionLevel.from_label(label)
                         if permission > workflow.permissions[key]:
@@ -232,4 +261,29 @@ class Workflow:
             else:
                 raise ValueError("permissions must be a string or a dictionary")
 
+            # Parse job information for flowchart
+            job = Job(id=job_id, name=job_data.get("name", job_id), uses=job_data.get("uses", None))
+
+            # Parse job dependencies
+            needs = job_data.get("needs", [])
+            if isinstance(needs, str):
+                job.needs = [needs]
+            elif isinstance(needs, list):
+                job.needs = needs
+
+            # Parse steps
+            for step_data in job_data.get("steps", []):
+                step_name = step_data.get("name", "")
+                step_uses = step_data.get("uses", "")
+                step_run = step_data.get("run", "")
+
+                step = Step(
+                    name=step_name,
+                    uses=step_uses,
+                    run=step_run,
+                )
+                job.steps.append(step)
+
+            workflow.jobs[job.id] = job
+
         return workflow
